@@ -10,10 +10,12 @@ class PowerControl:
 
     def parse_protobuf(self, bytes):
         
+        parsed = {}
+
         try:
             proto = solaredge_setapp.power_control_pb2.PowerControl()
             proto.ParseFromString(bytes)
         except AttributeError as e:
             print(f"AttributeError: {e}")
 
-        return {}
\ No newline at end of file
+        return parsed
\ No newline at end of file
