@@ -10,21 +10,14 @@ class Region:
     
     def parse_protobuf(self, bytes):
         
-        # int country_id
-        # str country from enum solaredge_setapp.Countries
-        # int language_id
-        # str language from enum solaredge_setapp.Languages
-
         parsed = {}
 
         try:
             proto = solaredge_setapp.region_pb2.Region()
             proto.ParseFromString(bytes)
 
-            parsed = {
-                "country_id": int(proto.country.country),
-                "language_id": int(proto.language.language)
-            }
+            parsed["country_id"] = int(proto.country.country)
+            parsed["language_id"] = int(proto.language.language)
             
             try: 
                 parsed["country"] = solaredge_setapp.Countries(parsed["country_id"]).name
